Møller Auto lietoti auto » Audi A6 Sport 2.0 150kW aut
Description: Møller Auto piedāvā plašu mazlietotu automobiļu izvēli. Mēs arī garantējam, ka automobilis, kuru Jūs pērkat, ir tādā (tehniskajā) stāvoklī, kādu Jūs to sagaidāt.

EST | LAT | LIT | ENG | RUS

- Par mums
- Lietotas automašīnas
- Kontakti

## Meklēt

Spiediet, lai atvērtu meklēšanu
Spiediet, lai aizvērtu meklēšanu
Cena: all
Jauda: all
Gads: all
Nobraukums: all
Tikai piedāvājumus
Aprīkojums
Adaptīvā pneimatiskā balstiekārta ar elektronisku amortizācijas kontroli
Adaptīva piekares regulēšana (DCC)
Kruīzkontrole
Braukšanas joslu maiņas asistents "Side Assist"
Braukšanas joslu uzturēšanas asistents "Lane Assist"
High beam control "Light Assist"
Atpakaļskata kamera
Vieglmetāla diski
LED priekšējie lukturi, automātiska lukturu augstuma regulēšana
DYNAUDIO skaņas sistēma
Navigācijas sistēma
Mobīlā telefona interfeiss
Ādas apdares sēdekļi
Apsildāms priekšējais vējstikls
Elektriski atverms aizmugurējais vāks
R line interjers
R line eksterjers
Piekabes āķis
Garantija
Meklēt pēc automašīnas reģistrācijas nr. - ievadiet numuru:

# Audi A6 Sport 2.0 150kW aut

Atpakaļ
Drukāt

Automašīnas ID: | 10236087 / E859213120
Valsts: | Lietuva
Dīleris: | Møller Auto Keturi žiedai Audi
Cena: | 62 600.00 € Cena ieskaitot PVN 21%

Līzinga kalkulators

Pirmā reģistrācija: | 05/2021
Nobraukums: | 9019 km
Reģistrācijas numurs: | 086735
Virsbūves (VIN) numurs: | WAUZZZF22MN086735
Tehniskā skate: | 05/2024
Dzinēja tilpums: | 2000 cm³
Degviela: | dīzelis
Degvielas patēriņš: | 6.0 l/100km
Jauda: | 204 ZS (150 kW)
Krāsa: | cita
Virsbūves tips: | universāls
Durvju skaits: | 4/5
Pārnesumkārba: | automātiskā
Piedziņa: | pilnpiedziņa
Garantija: | Ražotāja garantija

Piedziņa / ritošā

- quattro pilnpiedziņa

Pārnesumkārba

- S-tronic

Drošība un aizsardzība

- Elektromehānisks stūres pastiprinātājs
- ESC stabilitātes kontrole
- Elektromehāniskā stāvbremze
- Drošības spilveni
- Galvas drošības spilveni
- Isofix bērnu sēdeklīšu stiprinājumi
- Centrālā atslēga ar tālvadības pulti
- Imobilaizeris, startēšanas bloķētājs

Asistentu sistēmas

- Adaptīvā kruīzkontrole
- Audi pre sense - priekšējās daļas uzraudzība
- Audi pre sense - aizmugurējās daļas uzraudzība
- Braukšanas joslu maiņas asistents "Side Assist"
- 360° skata kameras
- Paralēlās un perpendikulārās novietošanas asistents "Park Assist"

Riepas un riteņi

- Vieglmetāla diski

Apgaismojums / lukturi

- Miglas lukturi priekšā
- Miglas lukturi aizmugurē
- Matrix-LED priekšējie lukturi

Multimēdiji

- MMI navigācija
- Mobīlā telefona interfeiss
- Multifunkcionāls krāsu displejs
- Vadītāja informācijas sistēma

Sēdekļi

- Ādas apdares sēdekļi
- Priekšējo sēdekļu apsilde
- Elektriski regulējami sēdēkļi
- Elkoņbalsts priekšā

Interjers / komforts

- Ādas stūre
- Multifunkciju stūre
- Heated steering wheel
- Sporta stūre
- Stūre ar ātrumu pārslēgšanas iespēju
- Ādas ātrumu pārslēdzējs
- Elektriski logu pacēlāji priekšā un aizmugurē
- Tekstila paklājiņi
- Elektriski regulējami spoguļi
- Spoguļu apsilde
- Nolokāmi spoguļi
- Interior lighting for a more colorful environment

Apsilde / kondicionēšana

- Četru zonu gaisa kondicionēšnas sistēma "Deluxe"

Aprīkojuma līnijas

- S-line eksterjera paka

Cits aprīkojums

- Servisa grāmatiņa
- Pagarinātā garantija

### Automašīnu var apskatīt:

Møller Auto Keturi žiedai Audi
Ukmergės g. 252
Vilnius LT-06120
Lietuva
E-pasts: evelina.paleviciene@moller.lt
Tālrunis: +370 5 2503613, +370 61429762
Apskati kartē
Evelina Palevičienė
E-pasts: evelina.paleviciene@moller.lt
Tālrunis: +37061429762
Mobīlais tālr.: +37061429762
Atpakaļ
Drukāt